@@ -3,8 +3,8 @@ use strict;
 use warnings;
 package Email::MIME;
 # ABSTRACT: easy MIME message handling
-$Email::MIME::VERSION = '1.932';
-use Email::Simple 2.104; # header_raw_*
+$Email::MIME::VERSION = '1.933';
+use Email::Simple 2.206; # header_raw
 use parent qw(Email::Simple);
 
 use Carp ();
@@ -805,7 +805,8 @@ sub _compose_content_type {
   my ($self, $ct_header) = @_;
   my $ct = join q{/}, @{$ct_header}{qw[type subtype]};
   for my $attr (sort keys %{ $ct_header->{attributes} }) {
-    $ct .= qq[; $attr="$ct_header->{attributes}{$attr}"];
+    next unless defined (my $value = $ct_header->{attributes}{$attr});
+    $ct .= qq[; $attr="$value"];
   }
   $self->header_raw_set('Content-Type' => $ct);
   $self->{ct} = $ct_header;
@@ -856,7 +857,7 @@ Email::MIME - easy MIME message handling
 
 =head1 VERSION
 
-version 1.932
+version 1.933
 
 =head1 SYNOPSIS
 
